@@ -1,6 +1,8 @@
 from .specification import Specification
 from .router import Router
 from .authorizer import Authorizer
+from .authorizer import ScopesFetcher
 from .validator import Validator
 from .operator import Operator
 from .operator import default_operation_id
+from .jsonschema import schematize
\ No newline at end of file
